Module consensus_app

Module consensus_app 

Consensus application implementation.

This module provides the implementation of the ConsensusApplication trait that applies finalized transactions to the node’s state (repositories, collaboration, authentication, etc.).

Structs

GutsApplication
The Guts application that applies consensus transactions to state.