pub fn create_backup(data_dir: &Path, output_path: &Path) -> Result<BackupInfo>Expand description
Create a backup of the node’s data directory.
This creates a compressed tarball of the data directory.
pub fn create_backup(data_dir: &Path, output_path: &Path) -> Result<BackupInfo>Create a backup of the node’s data directory.
This creates a compressed tarball of the data directory.