pub struct P2PManager {
pub public_key: PublicKey,
}Expand description
Legacy P2P manager stub for backward compatibility.
This will be replaced by the authenticated network for real consensus.
Fields
public_key: PublicKeyOur public key.
Implementations
Sourceimpl P2PManager
impl P2PManager
Sourcepub fn new(private_key: &PrivateKey) -> Self
pub fn new(private_key: &PrivateKey) -> Self
Create a new P2P manager stub.
Sourcepub fn notify_update(
&self,
_repo_key: &str,
_new_objects: Vec<ObjectId>,
_refs: Vec<(String, ObjectId)>,
)
pub fn notify_update( &self, _repo_key: &str, _new_objects: Vec<ObjectId>, _refs: Vec<(String, ObjectId)>, )
Stub: Notify peers about a repository update.
In the real consensus system, replication happens via the consensus layer.
Sourcepub fn register_repo(&self, _key: String, _repo: Arc<Repository>)
pub fn register_repo(&self, _key: String, _repo: Arc<Repository>)
Stub: Register a repository for replication.
In the real consensus system, repositories are replicated via consensus.