pub fn start_simplex_consensus(
config: SimplexConsensusConfig,
) -> Result<SimplexConsensusHandle, String>Expand description
Start the Simplex BFT consensus engine.
This spawns a new thread that runs the commonware runtime with the consensus engine. The engine will connect to other validators via P2P and participate in BFT consensus.
Returns a handle that can be used to interact with the consensus engine.